You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by as...@apache.org on 2005/08/16 16:15:44 UTC

svn commit: r232998 - in /webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc: ./ encoding/ handler/ handler/soap/ holders/ http/ security/ server/ soap/

Author: ashutosh
Date: Tue Aug 16 07:14:59 2005
New Revision: 232998

URL: http://svn.apache.org/viewcvs?rev=232998&view=rev
Log:
refactor and cleanup

Added:
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Endpoint.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebServiceException.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/http/
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/MessageSecurity.java
Removed:
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Call.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/JAXRPCContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/JAXRPCException.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/encoding/
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/AbstractHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/GenericHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerChain.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerInfo.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerLifecycle.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/holders/
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/server/
Modified:
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/AsyncHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Binding.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/BindingProvider.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Dispatch.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/LogicalMessage.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/NamespaceConstants.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterIndex.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterMode.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ProtocolException.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Provider.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Response.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Service.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceException.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceFactory.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceMode.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Stub.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebFault.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/Handler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerRegistry.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalMessageContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/MessageContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPMessageContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/SecurityConfiguration.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPBinding.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPFaultException.java

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/AsyncHandler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/AsyncHandler.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/AsyncHandler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/AsyncHandler.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface AsyncHandler<T>

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Binding.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Binding.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Binding.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Binding.java Tue Aug 16 07:14:59 2005
@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.util.List;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.security.SecurityConfiguration;
+import javax.xml.ws.handler.Handler;
+import javax.xml.ws.security.SecurityConfiguration;
 
 /**
  * @author sunja07
@@ -32,21 +32,21 @@
 	 * 
 	 * @return java.util.List Handler chain
 	 */
-	List<HandlerInfo> getHandlerChain();
+	List<Handler> getHandlerChain();
 	
 	/**
 	 * Method setHandlerChain
 	 * Sets the handler chain for the protocol binding instance.
 	 * 
 	 * @param chain - A List of handler configuration entries
-	 * @throws JAXRPCException - On an error in the configuration of the 
+	 * @throws WebServiceException - On an error in the configuration of the 
 	 * handler chain 
 	 java.lang.UnsupportedOperationException - If this operation is not 
 	 supported. This may be done to avoid any overriding of a pre-configured 
 	 handler chain.
 	 */
-	void setHandlerChain(java.util.List<HandlerInfo> chain) throws 
-	JAXRPCException;
+	void setHandlerChain(java.util.List<Handler> chain) throws 
+	WebServiceException, UnsupportedOperationException;
 	
 	/**
 	 * Method getSecurityConfiguration

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/BindingProvider.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/BindingProvider.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/BindingProvider.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/BindingProvider.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface BindingProvider
@@ -22,7 +22,7 @@
  * binding and associated JAXRPCContext objects for request and response 
  * message processing.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
 public interface BindingProvider {
@@ -33,7 +33,7 @@
 	 * protocol/transport binding for the binding in use. 
 	 */
 	static final java.lang.String ENDPOINT_ADDRESS_PROPERTY = 
-		"javax.xml.rpc.service.endpoint.address";
+		"javax.xml.ws.service.endpoint.address";
 	
 	/**
 	 * Standard property: This boolean property is used by a service client to 
@@ -44,7 +44,7 @@
 	 * false.
 	 */
 	static final java.lang.String SESSION_MAINTAIN_PROPERTY = 
-		"javax.xml.rpc.session.maintain";
+		"javax.xml.ws.session.maintain";
 	
 	/**
 	 * Standard property for SOAPAction. This boolean property indicates 
@@ -52,55 +52,47 @@
 	 * property is false indicating that the SOAPAction is not used.
 	 */
 	static final java.lang.String SOAPACTION_USE_PROPERTY = 
-		"javax.xml.rpc.soap.http.soapaction.use";
+		"javax.xml.ws.soap.http.soapaction.use";
 	
 	/**
 	 * Standard property for SOAPAction. Indicates the SOAPAction URI if the 
 	 * javax.xml.rpc.soap.http.soapaction.use property is set to true.
 	 */
 	static final java.lang.String SOAPACTION_URI_PROPERTY = 
-		"javax.xml.rpc.soap.http.soapaction.uri";
+		"javax.xml.ws.soap.http.soapaction.uri";
 	
 	/**
 	 * Standard property: Password for authentication.
 	 */
 	static final java.lang.String PASSWORD_PROPERTY = 
-		"javax.xml.rpc.security.auth.password";
+		"javax.xml.ws.security.auth.password";
 	
 	/**
 	 * Standard property: User name for authentication.
 	 */
 	static final java.lang.String USERNAME_PROPERTY = 
-		"javax.xml.rpc.security.auth.username";
-	
-	/**
-	 * Standard property: JAXB context to use for marshalling arguments in 
-	 * dynamic APIs.
-	 */
-	static final java.lang.String JAXB_CONTEXT_PROPERTY = 
-		"javax.xml.rpc.binding.context";
+		"javax.xml.ws.security.auth.username";
 	
 	/**
 	 * Method getRequestContext
-	 * Get the JAXRPCContext that is used to initialize the message context 
+	 * Get the Context that is used to initialize the message context 
 	 * for request messages. Modifications to the request context do not 
 	 * affect the message context of either synchronous or asynchronous 
 	 * operations that have already been started.
-	 * @return The JAXRPCContext that is used in processing request messages.
+	 * @return The context that is used in processing request messages.
 	 */
-	JAXRPCContext getRequestContext();
+	java.util.Map<java.lang.String,java.lang.Object> getRequestContext();
 	
 	/**
 	 * Method getResponseContext
-	 * Get the JAXRPCContext that resulted from processing a response message. 
+	 * Get the Context that resulted from processing a response message. 
 	 * The returned context is for the most recently completed synchronous 
 	 * operation. Subsequent synchronous operation invocations overwrite the 
 	 * response context. Asynchronous operations return their response context 
 	 * via the Response interface.
-	 * @return The JAXRPCContext that resulted from processing the latest 
-	 * response messages.
+	 * @return The context that resulted from processing the latest response messages.
 	 */
-	JAXRPCContext getResponseContext();
+	java.util.Map<java.lang.String,java.lang.Object> getResponseContext();
 	
 	/**
 	 * Method getBinding

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Dispatch.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Dispatch.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Endpoint.java (added)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Endpoint.java Tue Aug 16 07:14:59 2005
@@ -0,0 +1,32 @@
+package javax.xml.ws;
+
+/**
+ * A Web service endpoint.
+ * <p>
+ * Endpoints are created using the EndpointFactory  class. An endpoint is always tied to one Binding  and one implementor,
+ * both set at endpoint creation time.
+ * <p>
+ * An endpoint is either in a published or an unpublished state. The publish methods can be used to start publishing an endpoint,
+ * at which point it starts accepting incoming requests. Conversely, the stop method can be used to stop accepting incoming
+ * requests and take the endpoint down.
+ * <p>
+ * An Executor may be set on the endpoint in order to gain better control over the threads used to dispatch incoming requests.
+ * For instance, thread pooling with certain parameters can be enabled by creating a ThreadPoolExecutor and registering it with
+ * the endpoint.
+ * <p>
+ * Handler chains can be set using the contained Binding.
+ * <p>
+ * An endpoint may have a list of metadata documents, such as WSDL and XMLSchema documents, bound to it. At publishing
+ * time, the JAX-WS implementation will try to reuse as much of that metadata as possible instead of generating new one based on
+ *  the annotations present on the implementor.
+ *  <p>
+ *  @since JAX-WS 2.0
+ * @author shaas02
+ * @see     EndpointFactory.createEndpoint(java.net.URI, java.lang.Object), Binding, Executor
+ */
+public interface Endpoint {
+
+	static final java.lang.String WSDL_SERVICE = "javax.xml.ws.wsdl.service";
+	
+	static final java.lang.String WSDL_PORT = "javax.xml.ws.wsdl.port";
+}

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/LogicalMessage.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/LogicalMessage.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/NamespaceConstants.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/NamespaceConstants.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Class NamespaceConstants

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterIndex.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterIndex.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterIndex.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterIndex.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.lang.annotation.*;
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterMode.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterMode.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterMode.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ParameterMode.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Class ParameterMode

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ProtocolException.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ProtocolException.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ProtocolException.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ProtocolException.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.io.Serializable;
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Provider.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Provider.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Provider.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Provider.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface Provider<T>
@@ -24,7 +24,7 @@
  * be used to control whether the Provider instance will receive entire 
  * protocol messages or just message payloads.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
 public interface Provider<T> {
@@ -45,7 +45,7 @@
 	 * ProtocolException to control the protocol level representation of the 
 	 * exception.
 	 */
-	T invoke(T request, JAXRPCContext context)
+	T invoke(T request, java.util.Map<java.lang.String,java.lang.Object> context)
 	         throws java.rmi.RemoteException;
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Response.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Response.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Response.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Response.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.util.concurrent.Future;
 
@@ -33,5 +33,5 @@
 	 * @return The contained response context. May be null if a response is 
 	 * not yet available.
 	 */
-	JAXRPCContext getContext();
+	java.util.Map<java.lang.String,java.lang.Object> getContext();
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Service.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Service.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Service.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Service.java Tue Aug 16 07:14:59 2005
@@ -14,11 +14,10 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
-import javax.xml.rpc.encoding.TypeMappingRegistry;
-import javax.xml.rpc.security.SecurityConfiguration;
-import javax.xml.rpc.handler.HandlerRegistry;
+import javax.xml.ws.handler.HandlerRegistry;
+import javax.xml.ws.security.SecurityConfiguration;
 
 /**
  * Interface Service
@@ -91,7 +90,7 @@
 	 * the dynamic proxy or stub instance 
 	 * @return java.rmi.Remote Stub instance or dynamic proxy that supports the 
 	 * specified service endpoint interface 
-	 * @throws ServiceException This exception is thrown in the following 
+	 * @throws WebServiceException This exception is thrown in the following 
 	 * cases:
 	 * 1. If there is an error in creation of the dynamic proxy or stub 
 	 * instance
@@ -100,9 +99,9 @@
 	 * specified
 	 * @see java.lang.reflect.Proxy, java.lang.reflect.InvocationHandler 
 	 */
-	java.rmi.Remote getPort(javax.xml.namespace.QName portName,
-            java.lang.Class serviceEndpointInterface)
-            throws ServiceException;
+	<T> T getPort(javax.xml.namespace.QName portName,
+            java.lang.Class<T> serviceEndpointInterface)
+            throws WebServiceException;
 	
 	/**
 	 * Method getPort
@@ -124,24 +123,22 @@
 	 * 2. If there is any missing WSDL metadata as required by this method
 	 * 3. Optionally, if an illegal serviceEndpointInterface is specified 
 	 */
-	java.rmi.Remote getPort(java.lang.Class serviceEndpointInterface)
+	<T> T getPort(java.lang.Class<T> serviceEndpointInterface)
     throws ServiceException;
 	
 	/**
-	 * Method createPort
-	 * Creates a new port for the service. Ports created in this way contain 
-	 * no WSDL port type information and can only be used for creating Dispatch
-	 *  and Call instances.
-	 * @param portName Qualified name for the target service endpoint
-	 * @param bindingId A URI identifier of a binding.
-	 * @param endpointAddress Address of the target service endpoint as a URI 
-	 * @throws ServiceException If any error in the creation of the port
-	 * @see javax.xml.rpc.soap.SOAPBinding.SOAP11HTTP_BINDING
-	 */
-	void createPort(javax.xml.namespace.QName portName,
-            java.net.URI bindingId,
-            java.lang.String endpointAddress)
-            throws ServiceException;
+	 * Creates a new port for the service. Ports created in this way contain no WSDL port type information and can only
+	 * be used for creating Dispatchinstances.
+	 * <p>
+	 * @param portName - Qualified name for the target service endpoint
+	 * @param bindingId - A URI identifier of a binding.
+	 * @param endpointAddress - Address of the target service endpoint as a URI
+	 * @throws WebServiceException - If any error in the creation of the port
+	 */
+	void addPort(javax.xml.namespace.QName portName,
+			java.net.URI bindingId,
+			java.lang.String endpointAddress) throws
+			WebServiceException;
 	
 	// This involves generics, needs a revisit
 	/**
@@ -158,14 +155,14 @@
 	 *  parameter controls whether the user will work with SOAP messages or the
 	 *  contents of a SOAP body. Mode must be MESSAGE when type is SOAPMessage.
 	 * @return Dispatch instance 
-	 * @throws ServiceException - If any error in the creation of the Dispatch
+	 * @throws WebServiceException - If any error in the creation of the Dispatch
 	 *  object
 	 * @see javax.xml.transform.Source, javax.xml.soap.SOAPMessage
 	 */
 	<T> Dispatch<T> createDispatch(javax.xml.namespace.QName portName,
             java.lang.Class<T> type,
             Service.Mode mode)
-        throws ServiceException;
+        throws WebServiceException;
       
 	// This involves generics, needs a revisit
 	/**
@@ -181,7 +178,7 @@
 	 *  protocol, this parameter controls whether the user will work with 
 	 *  SOAP messages or the contents of a SOAP body.
 	 * @return Dispatch instance 
-	 * @throws ServiceException - If any error in the creation of the Dispatch
+	 * @throws WebServiceException - If any error in the creation of the Dispatch
 	 *  object
 	 * @see JAXBContext
 	 */
@@ -189,73 +186,7 @@
 			javax.xml.namespace.QName portName,
             javax.xml.bind.JAXBContext context,
             Service.Mode mode)
-            throws ServiceException;
-     
-	/**
-	 * Method getCalls
-	 * Gets an array of preconfigured Call objects for invoking operations on 
-	 * the specified port. There is one Call object per operation that can be 
-	 * invoked on the specified port. Each Call object is pre-configured and 
-	 * does not need to be configured using the setter methods on Call 
-	 * interface.
-	 * Each invocation of the getCalls method returns a new array of 
-	 * preconfigured Call objects 
-	 * This method requires the Service implementation class to have access to
-	 * the WSDL related metadata.
-	 * @param portName Qualified name for the target service endpoint 
-	 * @return Call[] Array of pre-configured Call objects 
-	 * @throws ServiceException If this Service class does not have access to 
-	 * the required WSDL metadata or if an illegal portName is specified.
-	 */
-	Call[] getCalls(javax.xml.namespace.QName portName)
-    throws ServiceException;
-	
-	/**
-	 * Method createCall
-	 * Creates a Call instance.
-	 * @param portName Qualified name for the target service endpoint 
-	 * @return Call instance 
-	 * @throws ServiceException If any error in the creation of the Call object
-	 */
-	Call createCall(javax.xml.namespace.QName portName)
-    throws ServiceException;
-	
-	/**
-	 * Method createCall
-	 * Creates a Call instance. 
-	 * @param portName Qualified name for the target service endpoint
-	 * @param operationName Qualified Name of the operation for which this 
-	 * Call object is to be created.
-	 * @return Call instance 
-	 * @throws ServiceException If any error in the creation of the Call object
-	 */
-	Call createCall(javax.xml.namespace.QName portName,
-            javax.xml.namespace.QName operationName)
-            throws ServiceException;
-	
-	/**
-	 * Method createCall
-	 * Creates a Call instance. 
-	 * @param portName Qualified name for the target service endpoint
-	 * @param operationName Name of the operation for which this Call object 
-	 * is to be created.
-	 * @return Call instance
-	 * @throws ServiceException If any error in the creation of the Call 
-	 * object
-	 */
-	Call createCall(javax.xml.namespace.QName portName,
-            java.lang.String operationName)
-            throws ServiceException;
-	
-	/**
-	 * Method createCall
-	 * Creates a Call object not associated with specific operation or target 
-	 * service endpoint. This Call object needs to be configured using the 
-	 * setter methods on the Call interface.
-	 * @return Call object
-	 * @throws ServiceException If any error in the creation of the Call object
-	 */
-	Call createCall() throws ServiceException;
+            throws WebServiceException;
 	
 	/**
 	 * Method getServiceName
@@ -270,10 +201,10 @@
 	 * by this service
 	 * @return Returns java.util.Iterator with elements of type 
 	 * javax.xml.namespace.QName 
-	 * @throws ServiceException If this Service class does not have access to 
+	 * @throws WebServiceException If this Service class does not have access to 
 	 * the required WSDL metadata
 	 */
-	java.util.Iterator getPorts() throws ServiceException;
+	java.util.Iterator getPorts() throws WebServiceException;
 	
 	/**
 	 * Method getWSDLDocumentLocation
@@ -283,19 +214,6 @@
 	java.net.URL getWSDLDocumentLocation();
 	
 	/**
-	 * Method getTypeMappingRegistry
-	 * Gets the TypeMappingRegistry for this Service object. The returned 
-	 * TypeMappingRegistry instance is pre-configured to support the standard 
-	 * type mapping between XML and Java types types as required by the 
-	 * JAX-RPC specification.
-	 * @return The TypeMappingRegistry for this Service object.
-	 * @throws java.lang.UnsupportedOperationException if the Service class 
-	 * does not support the configuration of TypeMappingRegistry.
-	 */
-	TypeMappingRegistry getTypeMappingRegistry() throws 
-	java.lang.UnsupportedOperationException;
-	
-	/**
 	 * Method getSecurityConfiguration
 	 * Gets the SecurityConfiguration for this Service object. The returned 
 	 * SecurityConfiguration instance is used to initialize the security 
@@ -318,5 +236,22 @@
 	 */
 	HandlerRegistry getHandlerRegistry() throws 
 	java.lang.UnsupportedOperationException;
+	
+	/**
+	 * Returns the executor for this Serviceinstance. The executor is used for all asynchronous invocations that require
+	 * callbacks.
+	 * @return The java.util.concurrent.Executor to be used to invoke a callback.
+	 * @see Executor
+	 */
+	java.util.concurrent.Executor getExecutor();
+	
+	/**
+	 * Sets the executor for this Service instance. The executor is used for all asynchronous invocations that require callbacks.
+	 * @param executor  - The java.util.concurrent.Executor  to be used to invoke a callback.
+	 * @throws java.lang.SecurityException - If the instance does not support setting an executor for security
+	 * reasons (e.g. the necessary permissions are missing).
+	 * @see Executor
+	 */
+	void setExecutor(java.util.concurrent.Executor executor) throws java.lang.SecurityException;
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceException.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceException.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceException.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceException.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.io.Serializable;
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceFactory.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceFactory.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceFactory.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceFactory.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Class ServiceFactory

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceMode.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceMode.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceMode.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/ServiceMode.java Tue Aug 16 07:14:59 2005
@@ -14,10 +14,11 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.lang.annotation.*;
-import javax.xml.rpc.Service.Mode;
+
+import javax.xml.ws.Service.Mode;
 
 /**
  * Annotation Type ServiceMode

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Stub.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Stub.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebFault.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebFault.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 import java.lang.annotation.*;
 

Added: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebServiceException.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebServiceException.java?rev=232998&view=auto
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebServiceException.java (added)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebServiceException.java Tue Aug 16 07:14:59 2005
@@ -0,0 +1,74 @@
+/*
+ * Copyright 2004,2005 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package javax.xml.ws;
+
+/**
+ * class JAXRPCException
+ * The javax.xml.rpc.JAXRPCException is thrown from the core JAX-RPC APIs to 
+ * indicate an exception related to the JAX-RPC runtime mechanisms.
+ * 
+ * @version 1.1
+ * @author sunja07
+ */
+public class WebServiceException extends RuntimeException implements 
+java.io.Serializable {
+
+	/**
+	 * Empty Constructor
+	 * Constructs a new exception with null as its detail message.
+	 */
+	public WebServiceException() {
+		super();
+	}
+	
+	/**
+	 * Constructor
+	 * Constructs a new exception with the specified detail message.
+	 * @param message - The detail message which is later retrieved using the 
+	 * getMessage method
+	 */
+	public WebServiceException(java.lang.String message) {
+		super(message);
+	}
+	
+	/**
+	 * Constructor
+	 * Constructs a new exception with the specified detail message and cause.
+	 * @param message - The detail message which is later retrieved using the 
+	 * getMessage method
+	 * @param cause - The cause which is saved for the later retrieval throw 
+	 * by the getCause method
+	 */
+	public WebServiceException(java.lang.String message,
+            java.lang.Throwable cause) {
+		super(message, cause);
+	}
+	
+	/**
+	 * Constructor
+	 * Constructs a new JAXRPCException with the specified cause and a detail 
+	 * message of (cause==null ? null : cause.toString()) (which typically 
+	 * contains the class and detail message of cause).
+	 * @param cause - The cause which is saved for the later retrieval throw 
+	 * by the getCause method. (A null value is permitted, and indicates that 
+	 * the cause is nonexistent or unknown.)
+	 */
+	public WebServiceException(java.lang.Throwable cause){
+		super(cause==null ? null : cause.toString(),cause);
+	}
+	
+}

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/Handler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/Handler.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/Handler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/Handler.java Tue Aug 16 07:14:59 2005
@@ -14,91 +14,77 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler;
+package javax.xml.ws.handler;
 
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.soap.SOAPFaultException;
+import javax.xml.ws.ProtocolException;
 
 /**
- * public interface Handler extends HandlerLifecycle
+ * public interface Handler<C extends MessageContext>
  * <p>
- * The javax.xml.rpc.handler.Handler interface is required to be implemented by a SOAP message handler. The
- * handleRequest, handleResponse and handleFault methods for a SOAP message handler get access to the SOAPMessage
- * from the SOAPMessageContext. The implementation of these methods can modify the SOAPMessage including the headers and
- * body elements.
- * @version 1.0
+ * The Handler interface is the base interface for JAX-WS handlers.
+ * @since .0
  * @author shaas02
  *
  */
-public interface Handler extends HandlerLifecycle {
+public interface Handler<C extends MessageContext> {
+	
+
+	/**
+	 * The handleMessage method is invoked for normal processing of inbound and outbound messages. Refer to the
+	 * description of the handler framework in the JAX-WS specification for full details.
+	 * <p>
+	 * @param context - the message context.
+	 * @return An indication of whether handler processing should continue for the current message
+	 *  - Return true to continue processing.
+	 *  - Return false to block processing.
+	 * @throws java.lang.RuntimeException - Causes the JAX-WS runtime to cease handler processing and generate a
+	 * fault.
+	 * @throws ProtocolException
+	 */
+	boolean handleMessage(C context) throws java.lang.RuntimeException, ProtocolException;
+	
 	
 	/**
-	 * The handleRequest method processes the request message.
-	 * @param context - MessageContext parameter provides access to the request message.
-	 * @return boolean Indicates the processing mode
-	 * 	-Return true to indicate continued processing of the request handler chain. The HandlerChain  takes the
-	 *  responsibility of invoking the next entity. The next entity may be the next handler in the HandlerChain or if
-	 * this handler is the last handler in the chain, the next entity is the service endpoint object.
-	 * -Return false to indicate blocking of the request handler chain. In this case, further processing of the request
-	 * handler chain is blocked and the target service endpoint is not dispatched. The JAX-RPC runtime system
-	 * takes the responsibility of invoking the response handler chain next with the SOAPMessageContext. The
-	 * Handler implementation class has the the responsibility of setting the appropriate response SOAP message in
-	 *  either handleRequest and/or handleResponse method. In the default processing model, the response handler
-	 * chain starts processing from the same Handler instance (that returned false) and goes backward in the
-	 * execution sequence.
-	 * @throws <code>JAXRPCException</code> - This exception indicates handler specific runtime error. If JAXRPCException is thrown by a
-	 * handleRequest method, the HandlerChain terminates the further processing of this handler chain. On the server side,
-	 *  the HandlerChain generates a SOAP fault that indicates that the message could not be processed for reasons not
-	 * directly attributable to the contents of the message itself but rather to a runtime error during the processing of the
-	 * message. On the client side, the exception is propagated to the client code
-	 * @throws <code>SOAPFaultException</code> - This indicates a SOAP fault. The Handler implementation class has the the responsibility
-	 * of setting the SOAP fault in the SOAP message in either handleRequest and/or handleFault method. If
-	 * SOAPFaultException is thrown by a server-side request handler's handleRequest method, the HandlerChain
-	 * terminates the further processing of the request handlers in this handler chain and invokes the handleFault method
-	 * on the HandlerChain with the SOAP message context. Next, the HandlerChain invokes the handleFault method on
-	 * handlers registered in the handler chain, beginning with the Handler instance that threw the exception and going
-	 * backward in execution. The client-side request handler's handleRequest method should not throw the
-	 * SOAPFaultException.
+	 * The handleFault method is invoked for fault message processing. Refer to the description of the handler framework in
+	 * the JAX-WS specification for full details.
+	 * @param context - the message context
+	 * @return An indication of whether handler fault processing should continue for the current message
+	 *  - Return true to continue processing.
+	 *  - Return false to block processing.
+	 * @throws java.lang.RuntimeException - Causes the JAX-WS runtime to cease handler fault processing and dispatch
+	 * the fault.
+	 * @throws ProtocolException - Causes the JAX-WS runtime to cease handler fault processing and dispatch the fault.
 	 */
-	boolean handleRequest(MessageContext context) throws JAXRPCException, SOAPFaultException;
+	boolean handleFault(C context) throws java.lang.RuntimeException, ProtocolException;
 	
 	/**
-	 * The handleResponse method processes the response SOAP message.
-	 * @param context - MessageContext parameter provides access to the response SOAP message
-	 * @return boolean Indicates the processing mode
-	 * - Return true to indicate continued processing ofthe response handler chain. The HandlerChain invokes the
-	 * handleResponse  method on the next Handler in the handler chain.
-	 * - Return false to indicate blocking of the response handler chain. In this case, no other response handlers in
-	 * the handler chain are invoked.
-	 * @throws <code>JAXRPCException</code> - Indicates handler specific runtime error. If JAXRPCException is thrown by a
-	 * handleResponse method, the HandlerChain terminates the further processing of this handler chain. On the server
-	 * side, the HandlerChain generates a SOAP fault that indicates that the message could not be processed for reasons
-	 * not directly attributable to the contents of the message itself but rather to a runtime error during the processing of
-	 * the message. On the client side, the runtime exception is propagated to the client code.
+	 * Called at the conclusion of a message exchange pattern just prior to the JAX-WS runtime disptaching a message, fault or
+	 * exception. Refer to the description of the handler framework in the JAX-WS specification for full details.
+	 * <p>
+	 * @param context  - the message context
 	 */
-	boolean handleResponse(MessageContext context) throws JAXRPCException;
+	void close(MessageContext context);
 	
 	/**
-	 * The handleFault method processes the SOAP faults based on the SOAP message processing model.
-	 * @param context - MessageContext parameter provides access to the SOAP message
-	 * @return boolean Indicates the processing mode
-	 * - Return true to indicate continued processing of SOAP Fault. The HandlerChain invokes the handleFault
-	 * method on the next Handler in the handler chain.
-	 * - Return false to indicate end of the SOAP fault processing. In this case, no other handlers in the handler
-	 * chain are invoked.
-	 * @throws <code>JAXRPCException</code> - Indicates handler specific runtime error. If JAXRPCException is thrown by a handleFault
-	 * method, the HandlerChain terminates the further processing of this handler chain. On the server side, the
-	 * HandlerChain generates a SOAP fault that indicates that the message could not be processed for reasons not
-	 * directly attributable to the contents of the message itself but rather to a runtime error during the processing of the
-	 * message. On the client side, the JAXRPCException is propagated to the client code.
+	 * The init method enables the handler instance to initialize itself. The init method passes the handler configuration as a
+	 * Map instance. The map is used to configure the handler (for example: setup access to an external resource or service)
+	 * during the initialization.
+	 * <p>
+	 * In the init method, the handler class may get access to any resources (for example; access to a logging service or
+	 * database) and maintain these as part of its instance variables. Note that these instance variables must not have any state
+	 * specific to the message processing performed in the various handle methods.
+	 * <p>
+	 * @param config - Configuration for the initialization of this handler
+	 * @throws RuntimeException - If initialization of the handler fails
 	 */
-	boolean handleFault(MessageContext context) throws JAXRPCException;
+	void init(java.util.Map<java.lang.String,java.lang.Object> config) throws RuntimeException;
 	
 	/**
-	 * Gets the header blocks that can be processed by this Handler instance.
-	 * @return Array of QNames of header blocks processed by this handler instance. QName is the qualified name of the
-	 * outermost element of the Header block.
+	 * The destroy method indicates the end of lifecycle for a Handler instance. The handler implementation class should
+	 * release its resources and perform cleanup in the implementation of the destroy method.
+	 * <p>
+	 * @throws RuntimeException - If any error during destroy
 	 */
-	javax.xml.namespace.QName[] getHeaders();
+	void destroy() throws RuntimeException;
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerRegistry.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerRegistry.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalHandler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalHandler.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler;
+package javax.xml.ws.handler;
 
 /**
  * public interface LogicalHandler<C extends <code>LogicalMessageContext</code>>
@@ -22,10 +22,10 @@
  * <p>
  * The javax.xml.rpc.handler.LogicalHandler extends AbstractHandler to provide typesafety for the message context
  * parameter.
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author shaas02
  *
  */
-public interface LogicalHandler<C extends LogicalMessageContext> extends AbstractHandler {
+public interface LogicalHandler<C extends LogicalMessageContext> extends Handler<C> {
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalMessageContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalMessageContext.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalMessageContext.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalMessageContext.java Tue Aug 16 07:14:59 2005
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler;
+package javax.xml.ws.handler;
 
-import javax.xml.rpc.LogicalMessage;
+import javax.xml.ws.LogicalMessage;
 
 /**
  * public interface LogicalMessageContext
@@ -24,7 +24,7 @@
  * <p>
  * The LogicalMessageContext interface extends MessageContext to provide access to a the contained message as a
  * protocol neutral LogicalMessage
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author shaas02
  *
  */

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/MessageContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/MessageContext.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/MessageContext.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/MessageContext.java Tue Aug 16 07:14:59 2005
@@ -14,18 +14,18 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler;
+package javax.xml.ws.handler;
 
 /**
  * The interface MessageContext abstracts the message context that is processed by a handler in the handle  method.
  * <p>
  * The MessageContext interface provides methods to manage a property set. MessageContext properties enable handlers in a
  * handler chain to share processing related state.
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author shaas02
- * @see <code>Handler</code>
  */
-public interface MessageContext {
+public interface MessageContext extends
+			java.util.Map<java.lang.String,java.lang.Object>{
 	
 	public static enum Scope {
 		APPLICATION,
@@ -37,85 +37,100 @@
 	 * <p>
 	 * Type: boolean
 	 */
-	static final java.lang.String MESSAGE_OUTBOUND_PROPERTY = "javax.xml.rpc.handler.message.outbound";
+	static final java.lang.String MESSAGE_OUTBOUND_PROPERTY = "javax.xml.ws.handler.message.outbound";
 	
 	/**
 	 * Standard property: security configuration.
 	 * <p>
 	 * Type: javax.xml.rpc.security.SecurityConfiguration
 	 */
-	static final java.lang.String MESSAGE_SECURITY_CONFIGURATION = "javax.xml.rpc.security.configuration";
+	static final java.lang.String MESSAGE_SECURITY_CONFIGURATION = "javax.xml.ws.security.configuration";
 	
 	/**
-	 * Sets the scope of a property.
-	 * @param name - Name of the property associated with the MessageContext
-	 * @param scope - Desired scope of the property
-	 * @throws java.lang.IllegalArgumentException - if an illegal property name is specified
+	 * Standard property: Map of attachments to a message, key is the MIME Content-ID, value is a DataHandler.
+	 * <p>
+	 * Type:  java.util.Map
 	 */
-	void setPropertyScope(java.lang.String name,
-			 MessageContext.Scope scope) throws java.lang.IllegalArgumentException;
+	static final java.lang.String MESSAGE_ATTACHMENTS = "javax.xml.ws.binding.attachments";
 	
 	/**
-	 * Gets the scope of a property.
-	 * @param name - Name of the property
-	 * @return Scope of the property
-	 * @throws java.lang.IllegalArgumentException - if a non-existant property name is specified
+	 * Standard property: input source for WSDL document.
+	 * <p>
+	 * Type: org.xml.sax.InputSource
 	 */
-	MessageContext.Scope getPropertyScope(java.lang.String name)throws java.lang.IllegalArgumentException;
+	static final java.lang.String WSDL_DESCRIPTION = "javax.xml.ws.wsdl.description";
 	
 	/**
-	 * Sets the name and value of a property associated with the MessageContext. If the MessageContext  contains a value of
-	 * the same property, the old value is replaced but the properties scope is unchanged. The scope of the property defaults to
-	 * HANDLER.
-	 * @param name - Name of the property associated with the MessageContext
-	 * @param value - Value of the property
-	 * @throws java.lang.IllegalArgumentException - If some aspect of the property prevents it from being stored in the context
-	 * @throws java.lang.UnsupportedOperationException - If this method is not supported.
+	 * Standard property: name of WSDL service.
+	 * <p>
+	 * Type: javax.xml.namespace.QName
 	 */
-	void setProperty(java.lang.String name,
-			java.lang.Object value) throws java.lang.IllegalArgumentException,
-			java.lang.UnsupportedOperationException;
+	static final java.lang.String WSDL_SERVICE = "javax.xml.ws.wsdl.service";
 	
 	/**
-	 * Sets the name, value and scope of a property associated with the MessageContext. If the MessageContext  contains a
-	 * value of the same property, the old value is replaced.
-	 * @param name - Name of the property associated with the MessageContext
-	 * @param value - Value of the property
-	 * @param scope - Desired scope of the property
-	 * @throws java.lang.IllegalArgumentException - If some aspect of the property prevents it from being stored in the context
-	 * @throws java.lang.UnsupportedOperationException - If this method is not supported.
+	 * Standard property: name of WSDL port.
+	 * <p>
+	 * Type: javax.xml.namespace.QName
 	 */
-	void setProperty(java.lang.String name,
-			java.lang.Object value,
-			MessageContext.Scope scope) throws java.lang.IllegalArgumentException,
-			java.lang.UnsupportedOperationException;
+	static final java.lang.String WSDL_PORT = "javax.xml.ws.wsdl.port";
 	
 	/**
-	 * Gets the value of a specific property from the MessageContext
-	 * @param name - Name of the property whose value is to be retrieved
-	 * @return Value of the property.
-	 * @throws java.lang.IllegalArgumentException - if an illegal property name is specified
+	 * Standard property: name of wsdl interface (2.0) or port type (1.1).
+	 * <p>
+	 * Type: javax.xml.namespace.QName
 	 */
-	java.lang.Object getProperty(java.lang.String name) throws java.lang.IllegalArgumentException;
+	static final java.lang.String WSDL_INTERFACE = "javax.xml.ws.wsdl.interface";
 	
 	/**
-	 * Removes a property (name-value pair) from the MessageContext
-	 * @param name - Name of the property to be removed
-	 * @throws java.lang.IllegalArgumentException - if an illegal property name is specified
+	 * Standard property: name of WSDL operation.
+	 * <p>
+	 * Type: javax.xml.namespace.QName
 	 */
-	void removeProperty(java.lang.String name) throws java.lang.IllegalArgumentException;
+	static final java.lang.String WSDL_OPERATION = "javax.xml.ws.wsdl.operation";
 	
 	/**
-	 * Returns true if the MessageContext contains a property with the specified name.
-	 * @param name  - Name of the property whose presense is to be tested
-	 * @return Returns true if the MessageContext contains the property; otherwise false
+	 * Standard property: HTTP response status code.
+	 * <p>
+	 * Type: java.lang.Integer
 	 */
-	boolean containsProperty(java.lang.String name);
+	static final java.lang.String HTTP_RESPONSE_CODE = "javax.xml.ws.http.response.code";
 	
 	/**
-	 * Returns an Iterator view of the names of the properties in this MessageContext
-	 * @return Iterator for the property names
+	 * Standard property: HTTP request headers.
+	 * <p>
+	 * Type: java.util.Map
+	 */
+	static final java.lang.String HTTP_REQUEST_HEADERS = "javax.xml.ws.http.request.headers";
+	
+	/**
+	 * Standard property: HTTP response headers.
+	 * <p>
+	 * Type: java.util.Map
+	 */
+	static final java.lang.String HTTP_RESPONSE_HEADERS = "javax.xml.ws.http.response.headers";
+	
+	/**
+	 * Standard property: HTTP request method.
+	 * <p>
+	 * Type: java.lang.String
+	 */
+	static final java.lang.String HTTP_REQUEST_METHOD = "javax.xml.ws.http.request.method";
+	
+	/**
+	 * Sets the scope of a property.
+	 * @param name - Name of the property associated with the MessageContext
+	 * @param scope - Desired scope of the property
+	 * @throws java.lang.IllegalArgumentException - if an illegal property name is specified
+	 */
+	void setScope(java.lang.String name,
+			 MessageContext.Scope scope) throws java.lang.IllegalArgumentException;
+	
+	/**
+	 * Gets the scope of a property.
+	 * @param name - Name of the property
+	 * @return Scope of the property
+	 * @throws java.lang.IllegalArgumentException - if a non-existant property name is specified
 	 */
-	java.util.Iterator getPropertyNames();
+	MessageContext.Scope getScope(java.lang.String name)throws java.lang.IllegalArgumentException;
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPHandler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPHandler.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPHandler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPHandler.java Tue Aug 16 07:14:59 2005
@@ -1,22 +1,21 @@
-package javax.xml.rpc.handler.soap;
+package javax.xml.ws.handler.soap;
 
-import javax.xml.rpc.handler.AbstractHandler;
+import javax.xml.ws.handler.Handler;
 
 /**
- * public interface SOAPHandler<C extends SOAPMessageContext>
- * extends AbstractHandler<C>
+ * public interface SOAPHandler<T extends SOAPMessageContext>
+ * extends Handler<T>
  * <p>
- * The javax.xml.rpc.handler.SOAPHandler extends AbstractHandler to provide 
- * typesafety for the message context parameter and add a method to obtain 
- * access to the headers that may be processed by the handler.
+ * The SOAPHandler class extends Handler  to provide typesafety for the message context parameter and add a method to obtain 
+ *  access to the headers that may be processed by the handler.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author shaas02
  *
- * @param <C>
+ * @param <T>
  */
-public interface SOAPHandler<C extends SOAPMessageContext>
-				extends AbstractHandler<C> {
+public interface SOAPHandler<T extends SOAPMessageContext>
+				extends Handler<T> {
 	
 	/**
 	 * Gets the header blocks that can be processed by this Handler instance.

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPMessageContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPMessageContext.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/MessageSecurity.java (added)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/MessageSecurity.java Tue Aug 16 07:14:59 2005
@@ -0,0 +1,41 @@
+package javax.xml.ws.security;
+
+import java.lang.annotation.*;
+
+/**
+ * The MessageSecurity annotation can be used to specify message-level security requirements on a class or method.
+ * <p>
+ * @since JAX-WS 2.0
+ * @author shaas02
+ *
+ */
+@Target(value={ElementType.TYPE,ElementType.METHOD})
+public @interface MessageSecurity {
+	
+	/**
+	 * Requested security features for outbound messages.
+	 * default = {INTEGRITY, CONFIDENTIALITY}
+	 */
+	public abstract SecurityConfiguration.SecurityFeature[] outboundSecurityFeatures();
+	
+	/**
+	 * Requested security features for inbound messages.
+	 * default = {INTEGRITY, CONFIDENTIALITY}
+	 */
+	public abstract SecurityConfiguration.SecurityFeature[] inboundSecurityFeatures();
+	
+	/**
+	 * Logical identifier of the configuration entry that describes how to fulfil the requested security features for inbound
+	 * messages.
+	 * default = "javax.xml.ws.security.default"
+	 */
+	public abstract java.lang.String inboundSecurityConfigId();
+	
+	/**
+	 * Logical identifier of the configuration entry that describes how to fulfil the requested security features for outbound
+	 * messages.
+	 * default = "javax.xml.ws.security.default"
+	 */
+	public abstract java.lang.String outboundSecurityConfigId();
+
+}

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/SecurityConfiguration.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/SecurityConfiguration.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/SecurityConfiguration.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/SecurityConfiguration.java Tue Aug 16 07:14:59 2005
@@ -14,14 +14,14 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.security;
+package javax.xml.ws.security;
 
 /**
  * Interface SecurityConfiguration
  * The interface SecurityConfiguration abstracts the message security 
  * configuration.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
 public interface SecurityConfiguration {
@@ -39,7 +39,7 @@
 	 * 		Establish or constrain the identity of the source and/or recipient
 	 * 		of a message 
 	 */
-	public static enum SecurityFeature { 
+	public static enum SecurityFeature{ 
 		//extends java.lang.Enum <SecurityConfiguration.SecurityFeature> {
 		
 		CONFIDENTIALITY , INTEGRITY , AUTHENTICATION ;
@@ -74,8 +74,8 @@
 		 */
 /*		public static SecurityConfiguration.SecurityFeature valueOf(java.lang.String name) throws java.lang.IllegalArgumentException {
 			
-		}
-*/
+		}*/
+
 	}
 	
 	/**

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPBinding.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPBinding.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPBinding.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPBinding.java Tue Aug 16 07:14:59 2005
@@ -14,9 +14,10 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.soap;
+package javax.xml.ws.soap;
 
-import javax.xml.rpc.Binding;
+import javax.xml.ws.Binding;
+import javax.xml.ws.WebServiceException;
 
 /**
  * Interface SOAPBinding
@@ -53,9 +54,38 @@
      * Sets the roles played by the SOAP binding instance.
      *
      * @param roles - The set of roles played by the binding instance.
-     * @throws JAXRPCException - On an error in the configuration of the 
+     * @throws WebServiceException - On an error in the configuration of the 
      * list of roles.
      */
     void setRoles(java.util.Set<java.net.URI> roles);
+    
+    /**
+     * Returns true if the use of MTOM is enabled.
+     * <p>
+     * @return true if and only if the use of MTOM is enabled.
+     */
+    boolean isMTOMEnabled();
+    
+    /**
+     * Enables or disables use of MTOM.
+     * <p>
+     * @param flag - A boolean specifying whether the use of MTOM should be enabled or disabled.
+     * @throws WebServiceException - If the specified setting is not supported by this binding instance.
+     */
+    void setMTOMEnabled(boolean flag) throws WebServiceException;
+    
+    /**
+     * Gets the SAAJ SOAPFactory instance used by this SOAP binding.
+     * <p>
+     * @return SOAPFactory instance used by this SOAP binding.
+     */
+    javax.xml.soap.SOAPFactory getSOAPFactory();
+    
+    /**
+     * Gets the SAAJ MessageFactory instance used by this SOAP binding.
+     * <p>
+     * @return MessageFactory instance used by this SOAP binding.
+     */
+    javax.xml.soap.MessageFactory getMessageFactory();
 
 }

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPFaultException.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPFaultException.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPFaultException.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/soap/SOAPFaultException.java Tue Aug 16 07:14:59 2005
@@ -14,106 +14,46 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.soap;
+package javax.xml.ws.soap;
 
-import javax.xml.rpc.ProtocolException;
-import javax.xml.soap.Detail;
-import javax.xml.namespace.QName;
+import javax.xml.ws.ProtocolException;
 
 /**
- * The SOAPFaultException exception represents a SOAP fault. 
- * The message part in the SOAP fault maps to the contents of faultdetail 
- * element accessible through the getDetail method on the SOAPFaultException. 
- * The method createDetail on the javax.xml.soap.SOAPFactory creates an 
- * instance of the javax.xml.soap.Detail.
- * The faultstring provides a human-readable description of the SOAP fault. 
- * The faultcode element provides an algorithmic mapping of the SOAP fault.
- * Refer to SOAP 1.1 and WSDL 1.1 specifications for more details of the SOAP 
- * faults.
+ * The SOAPFaultException exception represents a SOAP 1.1 or 1.2 fault.
+ * <p>
+ * A SOAPFaultException wraps a SAAJ SOAPFault  that manages the SOAP-specific representation of faults. The
+ * createFault method of javax.xml.soap.SOAPFactory may be used to create an instance of
+ * javax.xml.soap.SOAPFault for use with the constructor. SOAPBinding contains an accessor for the SOAPFactory used by
+ *  the binding instance.
+ *  <p>
+ *  Note that the value of getFault is the only part of the exception used when searializing a SOAP fault.
+ *  <p>
+ *  Refer to the SOAP specification for a complete description of SOAP faults.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
 public class SOAPFaultException extends ProtocolException {
 	
 	/**
-	 * Constructor for the SOAPFaultException 
-	 * @param faultcode QName for the SOAP faultcode
-	 * @param faultstring faultstring element of SOAP fault
-	 * @param faultactor faultactor element of SOAP fault
-	 * @param faultdetail faultdetail element of SOAP fault
-	 * @see javax.xml.soap.SOAPFactory#createDetail
+	 * Constructor for SOAPFaultException
+	 * @param fault - SOAPFault representing the fault
+	 * @see javax.xml.soap.SOAPFactory#createFault
 	 */
-	public SOAPFaultException(javax.xml.namespace.QName faultcode,
-            java.lang.String faultstring,
-            java.lang.String faultactor,
-            javax.xml.soap.Detail faultdetail){
-		
-		super(faultstring);
-		
-		this.faultcode   = faultcode;
-		this.faultstring = faultstring;
-		this.faultactor  = faultactor;
-		this.detail      = faultdetail;
+	public SOAPFaultException(javax.xml.soap.SOAPFault fault){
+		soapFault = fault;
 	}
 	
 	/**
-	 * Method getFaultCode
-	 * Gets the faultcode element. The faultcode element provides an 
-	 * algorithmic mechanism for identifying the fault. SOAP defines a small 
-	 * set of SOAP fault codes covering basic SOAP faults.
-	 * 
-	 * @return QName of the faultcode element
+	 * Gets the embedded SOAPFault instance.
+	 * @return javax.xml.soap.SOAPFault SOAP fault element
 	 */
-	public javax.xml.namespace.QName getFaultCode() {
-		return faultcode;
+	public javax.xml.soap.SOAPFault getFault(){
+		return soapFault;
 	}
-	
-	/**
-	 * Method getFaultString
-	 * Gets the faultstring element. The faultstring provides a human-readable
-	 * description of the SOAP fault and is not intended for algorithmic 
-	 * processing.
-	 * 
-	 * @return faultstring element of the SOAP fault
-	 */
-	public java.lang.String getFaultString() {
-		return faultstring;
-	}
-	
-	/**
-	 * Method getFaultActor
-	 * Gets the faultactor element. The faultactor element provides 
-	 * information about which SOAP node on the SOAP message path caused the 
-	 * fault to happen. It indicates the source of the fault.
-	 * 
-	 * @return faultactor element of the SOAP fault
-	 */
-	public java.lang.String getFaultActor() {
-		return faultactor;
-	}
-	
+
 	/**
-	 * Method getDetail
-	 * Gets the detail element. The detail element is intended for carrying 
-	 * application specific error information related to the SOAP Body. 
-	 * 
-	 * @return detail element of the SOAP fault
+	 * embedded soap fault instance
 	 */
-	public Detail getDetail() {
-		return detail;
-	}
-	
-    /** Qualified name of the faultcode. */
-    private QName faultcode;
-
-    /** The faultstring element of the SOAP fault. */
-    private String faultstring;
-
-    /** Faultactor element of the SOAP fault. */
-    private String faultactor;
-    
-    /** Detail element of the SOAP fault. */
-    private Detail detail;
-
+	private javax.xml.soap.SOAPFault soapFault;
 }
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Dispatch.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Dispatch.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface Dispatch<T>
@@ -22,10 +22,10 @@
  * invocation of a service endpoint operations. The javax.xml.rpc.Service 
  * interface acts as a factory for the creation of Dispatch instances.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
-public interface Dispatch<T> {
+public interface Dispatch<T> extends BindingProvider{
 	
 	/**
 	 * Method invoke
@@ -39,10 +39,10 @@
 	 * invocation.
 	 * @throws java.rmi.RemoteException - If a fault occurs during 
 	 * communication with the service
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance. 
 	 */
-	T invoke(T msg) throws java.rmi.RemoteException;
+	T invoke(T msg) throws java.rmi.RemoteException, WebServiceException;
 	
 	/**
 	 * Method invokeAsync
@@ -56,10 +56,11 @@
 	 * message used to invoke the operation.
 	 * @return The response message or message payload to the operation 
 	 * invocation.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance.
+	 * @throws java.rmi.RemoteException
 	 */
-	Response<T> invokeAsync(T msg) throws JAXRPCException;
+	Response<T> invokeAsync(T msg) throws java.rmi.RemoteException, WebServiceException;
 	
 	/**
 	 * Method invokeAsync
@@ -79,11 +80,11 @@
 	 * the results of the operation - the object returned from Future.get() 
 	 * is implementation dependent and any use of it will result in 
 	 * non-portable behaviour.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance
 	 */
 	java.util.concurrent.Future<?> invokeAsync(T msg,
-            AsyncHandler<T> handler) throws JAXRPCException;
+            AsyncHandler<T> handler) throws WebServiceException;
 	
 	/**
 	 * Method invokeOneWay
@@ -97,9 +98,9 @@
 	 * 
 	 * @param msg - An object that will form the message or payload of the 
 	 * message used to invoke the operation.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance or if an error occurs during the invocation.
 	 */
-	void invokeOneWay(T msg) throws JAXRPCException;
+	void invokeOneWay(T msg) throws WebServiceException;
 
 }
@@ -39,10 +39,10 @@
 	 * @throws java.rmi.RemoteException - If a fault occurs during 
 	 * communication with the service
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance. 
 	 */
@@ -56,10 +56,11 @@
 	 * @return The response message or message payload to the operation 
 	 * invocation.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance.
@@ -79,11 +80,11 @@
 	 * is implementation dependent and any use of it will result in 
 	 * non-portable behaviour.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance
 	 */
@@ -97,9 +98,9 @@
 	 * @param msg - An object that will form the message or payload of the 
 	 * message used to invoke the operation.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance or if an error occurs during the invocation.
 	 */

Added: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Endpoint.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Endpoint.java?rev=232998&view=auto
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/LogicalMessage.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/LogicalMessage.java Tue Aug 16 07:14:59 2005
@@ -14,14 +14,14 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface LogicalMessage
  * The LogicalMessage interface represents a protocol agnostic XML message 
  * and contains methods that provide access to the payload of the message.
  * 
- * @version 1.0
+ * @since JAX-WS 2.0
  * @author sunja07
  */
 public interface LogicalMessage {
@@ -49,22 +49,22 @@
 	 * message payload
 	 * @return The contained message payload; returns null if no payload is 
 	 * present in this message
 	 * @throws JAXRPCException If an error occurs when using a supplied 
 	 * JAXBContext to unmarshall the payload. The cause of the JAXRPCException
 	 * is the original JAXBException.
 	 */
 	java.lang.Object getPayload(javax.xml.bind.JAXBContext context) throws 
-	JAXRPCException;
+	WebServiceException;
 	
 	/**
 	 * Method setPayload
 	 * Sets the message payload
 	 * @param payload message payload 
 	 * @throws JAXRPCException If any error during the setting of the payload
 	 *  in this message java.lang.UnsupportedOperationException - If this 
 	 *  operation is not supported.
 	 */
-	void setPayload(javax.xml.transform.Source payload) throws JAXRPCException;	
+	void setPayload(javax.xml.transform.Source payload) throws WebServiceException;	
 	
 	/**
 	 * Method setPayload
@@ -74,10 +74,10 @@
 	 * payload 
 	 * @throws java.lang.UnsupportedOperationException If this operation is 
 	 * not supported
 	 * @throws JAXRPCException If an error occurs when using the supplied 
 	 * JAXBContext to marshall the payload. The cause of the JAXRPCException 
 	 * is the original JAXBException.
 	 */
 	void setPayload(java.lang.Object payload,
-            javax.xml.bind.JAXBContext context) throws JAXRPCException;
+            javax.xml.bind.JAXBContext context) throws WebServiceException;
 }
@@ -49,22 +49,22 @@
 	 * @return The contained message payload; returns null if no payload is 
 	 * present in this message
-	 * @throws JAXRPCException If an error occurs when using a supplied 
+	 * @throws WebServiceException If an error occurs when using a supplied 
 	 * JAXBContext to unmarshall the payload. The cause of the JAXRPCException
 	 * is the original JAXBException.
@@ -49,22 +49,22 @@
 	 * Sets the message payload
 	 * @param payload message payload 
-	 * @throws JAXRPCException If any error during the setting of the payload
+	 * @throws WebServiceException If any error during the setting of the payload
 	 *  in this message java.lang.UnsupportedOperationException - If this 
 	 *  operation is not supported.
@@ -74,10 +74,10 @@
 	 * @throws java.lang.UnsupportedOperationException If this operation is 
 	 * not supported
-	 * @throws JAXRPCException If an error occurs when using the supplied 
+	 * @throws WebServiceException If an error occurs when using the supplied 
 	 * JAXBContext to marshall the payload. The cause of the JAXRPCException 
 	 * is the original JAXBException.

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/NamespaceConstants.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/NamespaceConstants.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Stub.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/Stub.java Tue Aug 16 07:14:59 2005
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc;
+package javax.xml.ws;
 
 /**
  * Interface Stub
@@ -45,7 +45,7 @@
 	 * 
 	 * @param name - Name of the configuration property
 	 * @param value - Value of the property 
-	 * @throws JAXRPCException - 
+	 * @throws WebServiceException - 
 	 * 1. If an optional standard property name is specified, however this Stub
 	 *  implementation class does not support the configuration of this 
 	 *  property. 
@@ -54,7 +54,7 @@
 	 * 3. If there is any error in the configuration of a valid property.
 	 */
 	void _setProperty(java.lang.String name, java.lang.Object value) throws 
-	JAXRPCException;
+	WebServiceException;
 	
 	/**
 	 * Method _getProperty
@@ -64,11 +64,11 @@
 	 * 
 	 * @param name - Name of the property whose value is to be retrieved 
 	 * @return Value of the configuration property 
 	 * @throws JAXRPCException - if an invalid or unsupported property name 
 	 * is passed.
 	 */
 	java.lang.Object _getProperty(java.lang.String name) throws 
-	JAXRPCException;
+	WebServiceException;
 	
 	/**
 	 * Method _getPropertyNames
@@ -64,11 +64,11 @@
 	 * @param name - Name of the property whose value is to be retrieved 
 	 * @return Value of the configuration property 
-	 * @throws JAXRPCException - if an invalid or unsupported property name 
+	 * @throws WebServiceException - if an invalid or unsupported property name 
 	 * is passed.
 	 */

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebFault.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/WebFault.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerRegistry.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/HandlerRegistry.java Tue Aug 16 07:14:59 2005
@@ -14,22 +14,22 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler;
+package javax.xml.ws.handler;
 
 import java.io.Serializable;
-import javax.xml.rpc.JAXRPCException;
+
+import javax.xml.ws.WebServiceException;
 
 /**
  * public interface HandlerRegistry extends java.io.Serializable
- * The javax.xml.rpc.handler.HandlerRegistry provides support for the programmatic configuration of handlers in a
- * HandlerRegistry.
- * 
+ * The HandlerRegistry provides support for the programmatic configuration of handlers in a HandlerRegistry.
+ * <p>
  * Handler chains may be registered on a per-service, per-port and per -protcol binding basis. The complete handler chain for a
  * stub, dynamic proxy, Dispatch or Call instance is a concatenation of the per-service handler chain, the handler chain for the
  * relevent port and the handler chain for the protocol binding in use.
  * @version 1.0
  * @author shaas02
- * @see javax.xml.rpc.Service
+ * @see javax.xml.ws.Service
  *
  */
 public interface HandlerRegistry extends Serializable {
@@ -43,7 +43,7 @@
 	 * @return java.util.List Handler chain
 	 * @throws java.lang.IllegalArgumentException - If an invalid portName is specified
 	 */
-	java.util.List getHandlerChain(javax.xml.namespace.QName portName) throws java.lang.IllegalArgumentException;
+	java.util.List<Handler> getHandlerChain(javax.xml.namespace.QName portName) throws java.lang.IllegalArgumentException;
 	
 	/**
 	 * Sets the handler chain for the specified port as a java.util.List. Each element in this list is required to be of the Java
@@ -51,29 +51,29 @@
 	 * 
 	 * @param portName - Qualified name of the target service endpoint
 	 * @param chain - A List representing configuration for the handler chain
 	 * @throws JAXRPCException - If any error in the configuration of the handler chain
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.
 	 * @throws java.lang.IllegalArgumentException  - If an invalid portName is specified
 	 */
 	void setHandlerChain(javax.xml.namespace.QName portName,
-			java.util.List chain) throws JAXRPCException, java.lang.UnsupportedOperationException,
+			java.util.List<Handler> chain) throws WebServiceException, java.lang.UnsupportedOperationException,
 			java.lang.IllegalArgumentException;
 	
 	/**
 	 * Gets the handler chain for all ports in the service instance. The returned List is used to configure the handler chain.
 	 * @return java.util.List Handler chain
 	 */
-	java.util.List<HandlerInfo> getHandlerChain();
+	java.util.List<Handler> getHandlerChain();
 	
 	/**
 	 * Sets the handler chain for all ports in the service instance.
 	 * @param chain - A List of handler configuration entries
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.
 	 * @throws JAXRPCException - On an error in the configuration of the handler chain
 	 */
-	void setHandlerChain(java.util.List<HandlerInfo> chain) throws java.lang.UnsupportedOperationException, JAXRPCException;
+	void setHandlerChain(java.util.List<Handler> chain) throws java.lang.UnsupportedOperationException, WebServiceException;
 	
 	/**
 	 * Gets the handler chain for the specified protocol binding. The returned List is used to configure this specific handler chain
@@ -81,22 +81,22 @@
 	 * @param bindingId - A URI identifier of a binding.
 	 * @return java.util.List Handler chain
 	 * @throws java.lang.IllegalArgumentException - If an unknown bindingId is specified
-	 * @see javax.xml.rpc.soap.SOAPBinding#SOAP11HTTP_BINDING
+	 * @see javax.xml.ws.soap.SOAPBinding#SOAP11HTTP_BINDING
 	 */
-	java.util.List<HandlerInfo> getHandlerChain(java.net.URI bindingId) throws java.lang.IllegalArgumentException;
+	java.util.List<Handler> getHandlerChain(java.net.URI bindingId) throws java.lang.IllegalArgumentException;
 	
 	/**
 	 * Sets the handler chain for the specified protocol binding as a java.util.List.
 	 * @param bindingId  - A URI identifier of a binding.
 	 * @param chain - A List of handler configuration entries
 	 * @throws JAXRPCException  - On an error in the configuration of the handler chain
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.
 	 * @throws java.lang.IllegalArgumentException - If an unknown bindingId is specified
-	 * @see javax.xml.rpc.soap.SOAPBinding#SOAP11HTTP_BINDING
+	 * @see javax.xml.ws.soap.SOAPBinding#SOAP11HTTP_BINDING
 	 */
 	void setHandlerChain(java.net.URI bindingId,
-			java.util.List<HandlerInfo> chain) throws JAXRPCException,
+			java.util.List<Handler> chain) throws WebServiceException,
 			java.lang.UnsupportedOperationException, java.lang.IllegalArgumentException;
 
 }
@@ -51,29 +51,29 @@
 	 * @param portName - Qualified name of the target service endpoint
 	 * @param chain - A List representing configuration for the handler chain
-	 * @throws JAXRPCException - If any error in the configuration of the handler chain
+	 * @throws WebServiceException - If any error in the configuration of the handler chain
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.
@@ -51,29 +51,29 @@
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.
-	 * @throws JAXRPCException - On an error in the configuration of the handler chain
+	 * @throws WebServiceException - On an error in the configuration of the handler chain
 	 */
@@ -81,22 +81,22 @@
 	 * @param bindingId  - A URI identifier of a binding.
 	 * @param chain - A List of handler configuration entries
-	 * @throws JAXRPCException  - On an error in the configuration of the handler chain
+	 * @throws WebServiceException  - On an error in the configuration of the handler chain
 	 * @throws java.lang.UnsupportedOperationException - If this set operation is not supported. This is done to avoid
 	 * any overriding of a pre-configured handler chain.

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalHandler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/LogicalHandler.java?rev=232998&r1=232997&r2=232998&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPMessageContext.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/handler/soap/SOAPMessageContext.java Tue Aug 16 07:14:59 2005
@@ -14,10 +14,10 @@
  * limitations under the License.
  */
 
-package javax.xml.rpc.handler.soap;
+package javax.xml.ws.handler.soap;
 
-import javax.xml.rpc.handler.MessageContext;
-import javax.xml.rpc.JAXRPCException;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.handler.MessageContext;
 
 /**
  * public interface SOAPMessageContext
@@ -42,11 +42,11 @@
 	/**
 	 * Sets the SOAPMessage in this message context
 	 * @param message - SOAP message
 	 * @throws JAXRPCException - If any error during the setting of the SOAPMessage in this message context
 	 * @throws java.lang.UnsupportedOperationException - If this operation is not supported
 	 * 
 	 */
-	void setMessage(javax.xml.soap.SOAPMessage message) throws JAXRPCException, java.lang.UnsupportedOperationException;
+	void setMessage(javax.xml.soap.SOAPMessage message) throws WebServiceException, java.lang.UnsupportedOperationException;
 	
 	/**
 	 * Gets headers that have a particular qualified name from the message in the message context. Note that a SOAP message
@@ -57,20 +57,19 @@
 	 * roles currently being played by this SOAP node, see getRoles.
 	 * @return An array of unmarshalled headers; returns an empty array if no message is present in this message context or no
 	 * headers match the supplied qualified name.
 	 * @throws JAXRPCException  - If an error occurs when using the supplied JAXBContext to unmarshall. The cause of the
 	 * JAXRPCException is the original JAXBException.
 	 */
 	java.lang.Object[] getHeaders(javax.xml.namespace.QName header,
 			javax.xml.bind.JAXBContext context,
-			boolean allRoles) throws JAXRPCException;
+			boolean allRoles) throws WebServiceException;
 	
 	/**
 	 * Gets the SOAP actor roles associated with an execution of the handler chain. Note that SOAP actor roles apply to the
 	 * SOAP node and are managed using SOAPBinding.setRoles and SOAPBinding.getRoles. Handler instances in the
 	 * handler chain use this information about the SOAP actor roles to process the SOAP header blocks. Note that the SOAP
 	 * actor roles are invariant during the processing of SOAP message through the handler chain.
-	 * @return Array of URIs for SOAP actor roles
-	 * @see  <code>SOAPBinding.setRoles(java.util.Set)</code> , <code>SOAPBinding.getRoles()</code>
+	 * @return Array of URIs for SOAP actor roles	 
 	 */
-	java.lang.String[] getRoles();
+	java.util.Set<java.net.URI> getRoles();
 }
@@ -42,11 +42,11 @@
 	 * Sets the SOAPMessage in this message context
 	 * @param message - SOAP message
-	 * @throws JAXRPCException - If any error during the setting of the SOAPMessage in this message context
+	 * @throws WebServiceException - If any error during the setting of the SOAPMessage in this message context
 	 * @throws java.lang.UnsupportedOperationException - If this operation is not supported
 	 * 
@@ -57,20 +57,19 @@
 	 * @return An array of unmarshalled headers; returns an empty array if no message is present in this message context or no
 	 * headers match the supplied qualified name.
-	 * @throws JAXRPCException  - If an error occurs when using the supplied JAXBContext to unmarshall. The cause of the
+	 * @throws WebServiceException  - If an error occurs when using the supplied JAXBContext to unmarshall. The cause of the
 	 * JAXRPCException is the original JAXBException.
 	 */

Added: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/MessageSecurity.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/javax/xml/rpc/security/MessageSecurity.java?rev=232998&view=auto
==============================================================================